@@ -31,8 +31,7 @@ def usage_description() :
     an_usage_description = ' "mpirun --hostfile ~/.openmpi_hostfile -x LD_LIBRARY_PATH -x PATH -np ${a_number_processors} ${application} -case . -parallel"'
     an_usage_description += " --case-dir='.'"
     an_usage_description += " --solver-log='log.solver-run'"
-    an_usage_description += " --watched-keyword='Time = |End'"
-    an_usage_description += " --watching-timeout=120"
+    an_usage_description += " --watched-keyword='ExecutionTime = '"
     
     return an_usage_description
 
@@ -53,29 +52,21 @@ a_container.add_option( TransientOption( "--solver-log",
                                          action = "store",
                                          dest = "solver_log",
                                          help = "('%default', if not specified)",
-                                         default = 'log.solver' ) )
+                                         default = 'log.solver-run' ) )
 
-a_container.add_option( PersistentOption( "--watched-keyword",
-                                          metavar = "< location of files inside of the study >",
-                                          action = "store",
-                                          dest = "watched_keyword",
-                                          help = "('%default', if not specified)",
-                                          default = 'Time = |End' ) )
+a_container.add_option( TransientOption( "--watched-keyword",
+                                         metavar = "< location of files inside of the study >",
+                                         action = "store",
+                                         dest = "watched_keyword",
+                                         help = "('%default', if not specified)",
+                                         default = 'ExecutionTime = ' ) )
 
-a_container.add_option( PersistentOption( "--watching-timeout",
-                                          metavar = "< timeout for expecting of the 'whatched keyword', None - means indefinitely >",
-                                          type = "int",
-                                          action = "store",
-                                          dest = "watching_timeout",
-                                          help = "(%default, by default )",
-                                          default = None ) )
-
-a_container.add_option( PersistentOption( "--finish-hook",
-                                          metavar = "< executable to be run at the solver finish >",
-                                          action = "store",
-                                          dest = "finish_hook",
-                                          help = "('%default', if not specified)",
-                                          default = 'cloudflu-timestamps-hook' ) )
+a_container.add_option( TransientOption( "--finish-hook",
+                                         metavar = "< executable to be run at the solver finish >",
+                                         action = "store",
+                                         dest = "finish_hook",
+                                         help = "('%default', if not specified)",
+                                         default = 'cloudflu-timestamps-hook' ) )
 
 a_container.add_option( TransientOption( "--time-log",
                                          metavar = "< upload solver log per each timestamp >",
@@ -94,7 +85,7 @@ def extract( the_option_parser ) :
     if len( an_args ) != 0 :
         a_solver_run = ' '.join( an_args )
     else:
-        a_solver_run = 'cat ./log.solver'
+        a_solver_run = 'cat ./log.interFoam.cloudflu'
         pass
     print_d( "a_solver_run = '%s'\n" % a_solver_run )
 
@@ -108,26 +99,19 @@ def extract( the_option_parser ) :
     a_watched_keyword = an_options.watched_keyword
     print_d( "a_watched_keyword = '%s'\n" % a_watched_keyword )
 
-    a_watching_timeout = an_options.watching_timeout
-    print_d( "a_watching_timeout = %s\n" % a_watching_timeout )
-
     a_finish_hook = an_options.finish_hook
 
     a_time_log = an_options.time_log
 
-    return a_solver_run, a_case_dir, a_solver_log, a_watched_keyword, a_watching_timeout, a_time_log, a_finish_hook
+    return a_solver_run, a_case_dir, a_solver_log, a_watched_keyword, a_time_log, a_finish_hook
 
 
 #--------------------------------------------------------------------------------------
-def compose( the_solver_run, the_case_dir, the_solver_log, 
-             the_watched_keyword, the_watching_timeout,
-             the_time_log, the_finish_hook ) :
-
+def compose( the_solver_run, the_case_dir, the_solver_log, the_watched_keyword, the_time_log, the_finish_hook ) :
     a_compose = "'%s'" % the_solver_run
     a_compose += " --case-dir='%s'" % the_case_dir
     a_compose += " --solver-log='%s'" % the_solver_log
     a_compose += " --watched-keyword='%s'" % the_watched_keyword
-    a_compose += " --watching-timeout=%s" % the_watching_timeout
     a_compose += " --finish-hook='%s'" % the_finish_hook
 
     if the_time_log == True :
